# QuOCS: The optimization library
QuOCS (Quantum Optimal Control Suite) is a python software package for theoretical and experimental optimizations.
You can find here the core of the optimization algorithms used in the QuOCS - suite.

## Unittesting

[![Build Status](https://github.com/Quantum-OCS/QuOCS/actions/workflows/unit_testing_linux.yml/badge.svg)](https://github.com/Quantum-OCS/QuOCS/actions)
[![Build Status](https://github.com/Quantum-OCS/QuOCS/actions/workflows/unit_testing_windows.yml/badge.svg)](https://github.com/Quantum-OCS/QuOCS/actions)
[![Build Status](https://github.com/Quantum-OCS/QuOCS/actions/workflows/python_publish_PyPI.yml/badge.svg)](https://github.com/Quantum-OCS/QuOCS/actions)

## Installation
Install quocslib in your virtual environment

```bash
python -m pip install -e .
```

## Documentation 
https://quantum-ocs.github.io/QuOCS


## Tests
Now you are able to use the tests scripts in the tests folder
:)

